| nominatimlite-package | R Documentation |
Lightweight interface to the 'OpenStreetMap' 'Nominatim' API https://nominatim.org/release-docs/latest/. Extract coordinates from addresses, retrieve addresses from coordinates, look up amenities and addresses, and return results as 'tibble' or 'sf' objects.
Maintainer: Diego Hernangómez diego.hernangomezherrero@gmail.com (ORCID) [copyright holder]
Authors:
Diego Hernangómez diego.hernangomezherrero@gmail.com (ORCID) [copyright holder]
Other contributors:
Jindra Lacko (ORCID) [contributor, reviewer]
Alex White [contributor]
OpenStreetMap (For the data) [copyright holder]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.