View source: R/geo_address_lookup.R
| geo_address_lookup | R Documentation |
The lookup API queries the address and other details of one or more
OSM objects, such as nodes, ways or relations, and returns the
tibble associated with the query. See
geo_address_lookup_sf() for retrieving the data as an sf
object.
geo_address_lookup(
osm_ids,
type = c("N", "W", "R"),
lat = "lat",
long = "lon",
full_results = FALSE,
return_addresses = TRUE,
verbose = FALSE,
nominatim_server = "https://nominatim.openstreetmap.org/",
custom_query = list()
)
osm_ids |
Vector of OSM identifiers as numeric values, for example
|
type |
Character vector of the OSM object type associated with each
|
lat |
Latitude column name in the output data (default |
long |
Longitude column name in the output data (default |
full_results |
Return all available data from the Nominatim API.
If |
return_addresses |
Return input addresses with results if |
verbose |
If |
nominatim_server |
URL of the Nominatim server to use. Defaults to
|
custom_query |
Named list with API-specific parameters, for example
|
See https://nominatim.org/release-docs/latest/api/Lookup/ for additional
parameters to be passed to custom_query.
A tibble with the results that match the query.
Address lookup:
geo_address_lookup_sf()
Geocoding:
geo_address_lookup_sf(),
geo_amenity(),
geo_amenity_sf(),
geo_lite(),
geo_lite_sf(),
geo_lite_struct(),
geo_lite_struct_sf()
ids <- geo_address_lookup(osm_ids = c(46240148, 34633854), type = "W")
ids
several <- geo_address_lookup(c(146656, 240109189), type = c("R", "N"))
several
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.