| geo_lite | R Documentation |
Geocodes addresses given as character values and returns the
tibble associated with the query. See geo_lite_sf() for
retrieving the data as an sf object.
Corresponds to the free-form query search described in the API endpoint.
geo_lite(
address,
lat = "lat",
long = "lon",
limit = 1,
full_results = FALSE,
return_addresses = TRUE,
verbose = FALSE,
nominatim_server = "https://nominatim.openstreetmap.org/",
progressbar = TRUE,
custom_query = list()
)
address |
|
lat |
Latitude column name in the output data (default |
long |
Longitude column name in the output data (default |
limit |
Maximum number of results to return per input address. Note that each query returns a maximum of 50 results. |
full_results |
Return all available data from the Nominatim API.
If |
return_addresses |
Return input addresses with results if |
verbose |
If |
nominatim_server |
URL of the Nominatim server to use. Defaults to
|
progressbar |
Logical. If |
custom_query |
Named list with API-specific parameters, for example
|
See https://nominatim.org/release-docs/latest/api/Search/ for additional
parameters to be passed to custom_query.
A tibble with the results that match the query.
tidygeocoder::geo().
Geocoding:
geo_address_lookup(),
geo_address_lookup_sf(),
geo_amenity(),
geo_amenity_sf(),
geo_lite_sf(),
geo_lite_struct(),
geo_lite_struct_sf()
geo_lite("Madrid, Spain")
# Several addresses
geo_lite(c("Madrid", "Barcelona"))
# With options: restrict search to the United States
geo_lite(c("Madrid", "Barcelona"),
custom_query = list(countrycodes = "US"),
full_results = TRUE
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.