nominatimlite: Interface to the 'Nominatim' API
Source:R/nominatimlite-package.R
nominatimlite-package.RdProvides a lightweight interface to the 'Nominatim' API https://nominatim.org/release-docs/latest/. It supports free-form and structured address searches, searches for addresses from coordinates, amenity lookup and address lookup by 'OpenStreetMap' object identifier. It returns results as 'tibble' data frames or 'sf' objects.
Author
Maintainer: Diego Hernangómez diego.hernangomezherrero@gmail.com (ORCID) [copyright holder]
Authors:
Diego Hernangómez diego.hernangomezherrero@gmail.com (ORCID) [copyright holder]
Other contributors:
Jindra Lacko (ORCID) [contributor, reviewer]
Alex White [contributor]
OpenStreetMap contributors (For the osm_amenities data) [copyright holder]