Skip to contents

Lightweight interface to the 'OpenStreetMap' 'Nominatim' API https://nominatim.org/release-docs/latest/. Extract coordinates from addresses, retrieve addresses from coordinates, look up amenities and addresses, and return results as 'tibble' or 'sf' objects.

Author

Maintainer: Diego Hernangómez diego.hernangomezherrero@gmail.com (ORCID) [copyright holder]

Authors:

Other contributors:

  • Jindra Lacko (ORCID) [contributor, reviewer]

  • Alex White [contributor]

  • OpenStreetMap (For the data) [copyright holder]